"use strict";

require('../../mocha-config.js');

var Alias = require('../../../../main/js/map/data/Alias');
var GenericSearchPanel = require('../../../../main/js/gui/leftPanel/GenericSearchPanel');
var PanelControlElementType = require('../../../../main/js/gui/PanelControlElementType');

var chai = require('chai');
var assert = chai.assert;
var logger = require('../../logger');

describe('GenericSearchPanel', function() {

  it('contructor', function() {
    var map = helper.createCustomMap();
    helper.createSearchDbOverlay(map);

    new GenericSearchPanel({
      element : testDiv,
      customMap : map
    });
    assert.equal(logger.getWarnings().length, 0);
  });

  it('on searchResults changed', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var searchDbOverlay = helper.createSearchDbOverlay(map);

    new GenericSearchPanel({
      element : testDiv,
      customMap : map
    });

    var searchParams = {
      modelId : map.getModel().getId(),
      coordinates : new google.maps.Point(457.51, 356.84),
      zoom : 4,
    };

    return searchDbOverlay.searchByCoordinates(searchParams).then(function() {
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(testDiv.innerHTML.indexOf("Reaction") >= 0);
    });
  });

  it('on searchResults changed 2', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    var searchDbOverlay = helper.createSearchDbOverlay(map);

    new GenericSearchPanel({
      element : testDiv,
      customMap : map
    });

    return searchDbOverlay.searchByQuery("s1", false).then(function() {
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(testDiv.innerHTML.indexOf("s1") >= 0);
    });
  });

  it('search by query with no results', function() {
    var map = helper.createCustomMap();
    map.getModel().setId(15781);
    helper.createSearchDbOverlay(map);

    var panel = new GenericSearchPanel({
      element : testDiv,
      customMap : map
    });

    panel.getControlElement(PanelControlElementType.SEARCH_INPUT).value = "s1";

    return panel.searchByQuery().then(function() {
      assert.equal(logger.getWarnings().length, 0);
      assert.ok(testDiv.innerHTML.indexOf("s1") >= 0);
    });
  });


  describe('createReactionElement', function() {
    it('type in desc', function() {
      var map = helper.createCustomMap();
      helper.createSearchDbOverlay(map);

      var panel = new GenericSearchPanel({
        element : testDiv,
        customMap : map
      });
      var reaction = helper.createReaction(map);
      var reactionType = "XX TYPE";
      reaction.setType(reactionType);

      assert.ok(panel.createReactionElement(reaction).innerHTML.indexOf(reactionType) >= 0);
    });
  });

  describe('createAliasElement', function() {
    it('default', function() {
      var map = helper.createCustomMap();
      helper.createSearchDbOverlay(map);
      
      var aliasObj = {
        symbol : "S1_SYMB",
        formerSymbols : [],
        modelId : map.getId(),
        synonyms : [ "syn44" ],
        description : "DESCRIPTION",
        type : "Simple molecule",
        abbreviation : "ABREVIATION",
        name : "s1",
        bounds : {
          x : 170.0,
          y : 171.5,
          width : 70.0,
          height : 25.0
        },
        formula : "FORMULA",
        id : 380217,
        references: [],
      };
      var alias = new Alias(aliasObj);


      var panel = new GenericSearchPanel({
        element : testDiv,
        customMap : map
      });

      var aliasDiv = panel.createAliasElement(alias);
      assert.ok(aliasDiv.innerHTML);
    });

    
    it('full name in desc', function() {
      var map = helper.createCustomMap();
      helper.createSearchDbOverlay(map);

      var panel = new GenericSearchPanel({
        element : testDiv,
        customMap : map
      });
      var alias = helper.createAlias(map);

      alias.setFullName("xxx");
      assert.ok(panel.createAliasElement(alias).innerHTML.indexOf("Full name") >= 0);

      alias.setFullName("");
      assert.ok(panel.createAliasElement(alias).innerHTML.indexOf("Full name") === -1);
    });
  });

  describe('clear', function() {
    it('input text', function() {
      var map = helper.createCustomMap();
      helper.createSearchDbOverlay(map);

      new GenericSearchPanel({
        element : testDiv,
        customMap : map
      });

      $(".typeahead", testDiv)[0].value = "some input";
      return map.clearDbOverlays().then(function() {
        assert.equal("", $(":input", testDiv)[0].value);
      });
    });
  });

});
