"use strict";

var logger = require('../logger');

var AliasMarker = require('../../../main/js/map/marker/AliasMarker');
var IdentifiedElement = require('../../../main/js/map/data/IdentifiedElement');
var Submap = require('../../../main/js/map/Submap');
var chai = require('chai');
var assert = chai.assert;

describe('Submap', function() {
  it("simple contructor", function() {
    var map = helper.createCustomMap();

    var model = helper.createModel();

    var submap = new Submap(map, model);
    assert.ok(submap);
    assert.equal(logger.getWarnings().length, 0);
    assert.equal(logger.getErrors().length, 0);
  });

  it("open", function() {
    var map = helper.createCustomMap();

    var model = helper.createModel();

    var submap = new Submap(map, model);

    $(global.testDiv).dialog({
      autoOpen : false
    });

    submap.open(global.testDiv);

    $(global.testDiv).dialog("destroy");
    assert.ok(submap);
    assert.equal(logger.getWarnings().length, 0);
    assert.equal(logger.getErrors().length, 0);
  });

  it("getTopMap", function() {
    var map = helper.createCustomMap();

    var model = helper.createModel();

    var submap = new Submap(map, model);

    assert.ok(submap.getTopMap());
  });

  it("create marker for submap", function() {
    var map;
    var submap;
    var marker;
    var projectId = "complex_model_with_submaps";
    helper.setUrl("http://test/?id=" + projectId);
    GuiConnector.getParams["id"] = projectId;
    return ServerConnector.getProject(projectId).then(function(project) {
      map = helper.createCustomMap(project);
      submap = map.getSubmapById(16729);
      return submap.getModel().getAliasById(345330);
    }).then(function(alias) {
      marker = new AliasMarker({
        element : new IdentifiedElement(alias),
        map : submap
      });
      return marker.init();
    }).then(function() {
      assert.ok(marker.getAliasData());
    });
  });
});
